
/*** less variables ***/
@link: rgba(16, 139, 204, 1);
@brand-purple: rgba(51, 0, 111, 1); //New UW purple
@brand-gold: rgba(232, 211, 162, 1); //New UW gold
@brand-litegold: rgba(250, 242, 223, 1); //lite version
@green: rgba(3,153,3,1); //bright green
@red: rgba(217, 83, 79, 1);  //#d9534f Bootstrap @brand-danger
@warning-yellow: rgba(231, 213, 0, 1);
@gray-darker:  lighten(#000, 13.5%); // #222
@gray-dark:    lighten(#000, 20%);   // #333
@gray:         lighten(#000, 33.5%); // #555
@gray-light:   lighten(#000, 46.7%); // #777
@gray-lighter: lighten(#000, 93.5%); // #eee
@button-light: rgba(0, 0, 0, 0);

/*** global ***/

html, body { height: 100%; }

body {color:#333; }

h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6 {
    font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
    font-weight: 200;
    line-height: 1.1;
}


a {color: @link; text-decoration:none;}
a:hover, a:focus {color:@link; text-decoration:underline;}


.dummy {color:red !important;} //indicate the dynamic content element

/* Schedule/Scheduled button styling */
button.has-spinner {
	width: 85px;;
	text-align: center;
}

span.loading {
    display: none;
    position: absolute;
    z-index: 999;
    padding-left: 30px;
}

span.state-successful {
	color: @green;
}

.brand{
	font-family:"Helvetica Neue", Helvetica, Arial, sans-serif ;
	font-size: 22px;
	color:@brand-purple; 
	margin-top: 10px;
}

.glyphicon {
	padding-right: 5px;
}

/*** Quarter Header block ***/

/*** Search block ***/

.quarter{
	display: inline-block;
    text-transform: uppercase;
	margin-bottom: 10px;
	margin-right: 30px;
	margin-top: 0px;
}

.change-select{
	color:@link;
	font-size: 22px;
	margin-left: 20px;
}



.lcra-styled-select { //gp-style select triangle
   width: 30px;
   height: 34px;
   overflow: hidden;
   background: no-repeat right transparent;
   border: none;
   margin-left:-15px;

   select {
	   background: url('../img/fa-caret-down3.png')  no-repeat transparent;
	   background-size:15px 15px;
	   background-position: 5px 10px;
	   width: 30px;
	   padding: 5px 5px 5px 15px;
	   border-radius: 0;
	   border:0;
	   -webkit-appearance: none;
	   text-indent: 20px;
	   text-overflow: "";
	   z-index: 1000;
	   line-height:2;
	   //color:#fff;
										
   }
}


/*** Tab block ***/
.nav-tabs {
	margin-bottom: 10px;
	margin-top: 5px;
	min-width: 375px;
	
	h3.tab-label{
	font-size: 1.25em;
	font-family: inherit;
	font-weight: inherit;
	color:inherit;
	text-transform: none; 
	line-height: normal;
	margin-top: 0px;
	margin-bottom: 4px;
	}
	>li.active>a {
	font-weight: 600;
	color:@brand-purple;
	}
	>li.admin {
	float: right;
	}
}
/*** Course Search form blocks ***/

.tab-content{
	margin-bottom: 40px;
	min-width: 375px;
	::-webkit-input-placeholder {font-style: italic;}

	:-moz-placeholder { font-style: italic;} /* Firefox 18- */
	
	::-moz-placeholder { font-style: italic; } /* Firefox 19+ */

	:-ms-input-placeholder { font-style: italic; }
	
	.inputs-row { 
		display:inline-block;
	}
	.input-prefix{ 
		width:96px;
	}
	.input-crs {
		width:52px;
	}
	.input-section {
		width:52px;
	}
	
	/*** Room Search form blocks ***/
    .rooms-loading { position: absolute; margin-left: 80px; font-size: 20px; height: 40px; width: 40x;  }
	.input-rm { width: 120px; }
	.input-date { width: 160px; }
	.event-search { margin-top: 20px; }

}//.tab-content
   

/*** Search result block ***/
.result-display-container{ padding:0px;

    .waiting { width: 100%; margin-top: 20px; font-size: 45px; text-align: center; }

	.room-header{
		background-color: @brand-litegold;
		margin:20px 0px;
		padding: 4px 10px;
		h3 { 
			font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
			color:@gray-dark;
			margin-top:5px;
			margin-bottom: 0px; 
			font-weight: 400;
			letter-spacing: 0;
			text-transform: none;
			}

		.record-status-enable {
			color:@green;
			font-size: small;
			display: inline-block;
			margin-left: 10px;
			
			} 
		.record-status-disable {
			color:@red;
			font-size: small;
			display: inline-block;
			margin-left: 10px;
			.fa-warning {
				color:#e9e20a;
				}
			}
		.other-links {
			display: inline-block;
			padding-top: 10px;

			.xlist-icon{
			padding-right: 2px;	
			}
			
			.external-links{
				float: right;
			}
			.header-link-span {
				padding-left: 2px;
				padding-right: 5px;
				margin-top: -35px;
				margin-right: 5px;
				a.header-link {
					text-decoration: none;
					&:hover, &:focus{
						text-decoration: underline;
						
					}
				}
				
			}
		}
		.course-name {
			display: inline-block;
		}
	}//.room-header

	.result-list-container {
		h4 { color:@brand-purple; font-weight: 500; display: inline-block;
            small {
                a, span { padding-left: 8px; }
            }
        }
        .result-header {
            min-height: 52px;
	        .fa-warning {
				color: @warning-yellow;
				margin-left: 5px;
				margin-right: -6px;
			}
        }
		.batchswitch {
			display: inline-block;
			margin-right: 15px;
			margin-top: 5px;
            span.scheduled, span.unscheduled {
                display: none;
            }
            span.schedule-all {
                display: inline-block;
            }
		}
		.result-list-chunk{ //margin-top: 20px;
			ol {margin:0; padding-left:0; list-style: none; }
			.result-row-date { padding-left:0px; display:inline-block; width: 40px; }
			.result-row-day{ padding-left:0px; margin-right:5px; display:inline-block; width: 25px; }
			.result-row-time{ padding-left:0px; display:inline-block; width: 135px; }
			.result-row-room{ padding-left:0px; display:inline-block; width: 70px; }
			.result-row-event{ padding-left:0px; font-weight: 400; display:inline-block; }
				.result-row-contact{
				padding-left:10px;
				display:inline-block;
				width: 160px;
				white-space: nowrap;
				text-overflow: ellipsis;
				vertical-align: top;
				overflow: hidden;
				}
            .result-row-recorder{ padding-left: 0px; display: inline-block; width: 150px; }

			.result-row-switchbtn{ padding-left:10px; }
		}// .result-list-chunk
		.record-status-enable {
			color:@green;
			font-size: small;
			display: inline-block;
			margin-left: 10px;
			} 
		.record-status-disable {
			color:@red;
			font-size: small;
			display: inline-block;
			margin-left: 10px;
			}
	}//.result-list-container
	
	

}


//Styling for Spinners

//Rotating Refresh Icon Class
.glyphicon-refresh-animate {
   -webkit-animation-name: rotateThis;
   -webkit-animation-duration: 0.75s;
   -webkit-animation-iteration-count: infinite;
   -webkit-animation-timing-function: linear;
}

//Webkit Keyframes for rotating icon
@-webkit-keyframes "rotateThis" {
 from { 
        -webkit-transform: rotate( 0deg );  
    }
 to  { 
        -webkit-transform: rotate( 360deg ); 
    }
}



.spinner {
  display: inline-block;
  opacity: 0;
  width: 0;

  -webkit-transition: opacity 0.25s, width 0.25s;
  -moz-transition: opacity 0.25s, width 0.25s;
  -o-transition: opacity 0.25s, width 0.25s;
  transition: opacity 0.25s, width 0.25s;
}

.spinner.active {
	opacity: 1;
	width: auto;
}


.has-spinner.active {
  opacity: 1;
}

.has-spinner.active .spinner {
  opacity: 1;
  width: auto; /* This doesn't work, just fix for unkown width elements */
  color: grey;
  text-align: center;
}

.has-spinner.active .text {
  width: 0; /* This doesn't work, just fix for unkown width elements */
  content: '';
}

.btn-success.has-spinner.active .spinner{
	color: white;
}


//Styling for spinner --End


.text {
	opacity: 1;
	width: auto;
	content: 'Schedule';
}


/*** Schedule button block ***/
.schedule-button-cluster {
    > span {
        display: none;
        cursor: default;
        margin-right: 8px;
    }

    i.setting-active {
        color: @green;
    }

    .btn-group.scheduled {
        > button:first-child { //scheduled button (depressed)
			background-color:@green !important;
			color:white;
            border:1px solid @gray-light;
            text-align: center;
            border-radius: 5px !important;
            -webkit-border-radius: 5px !important;
            -moz-border-radius: 5px !important;
            display: block;
            width: 120px;
            font-size: 15px;
            margin: -5px;
            i { //checkmark inside the button
                display: inline;
            }
        }
    }
    .btn-group.scheduled {
        span.unscheduled {
            display: none;
        }
    }
    .btn-group.unscheduled {
        > button:first-child { //unscheduled button (not depressed)
            background-color: @button-light;
            border:1px solid @gray-light;
            text-align: center;
            border-radius: 5px !important;
            -webkit-border-radius: 5px !important;
            -moz-border-radius: 5px !important;
            display: block;
            width: 120px;
            font-size: 15px;
            margin: -5px;
        }
    }
    .btn-group.unscheduled {
        span.scheduled {
            display: none;
        }
    }
    .schedule-all {
        display: none;
    }
}

.btn[disabled] {
	opacity:.4;
}


.footer{
	color:#666;
	font-size: 12px;
}



/*** restclients overrides ***/
.restclients-proxy { background: #e5e5e5; margin-bottom: 2em;border-radius: 4px;padding: 5px;}
.restclients-header { line-height: 34px; }
.restclients-header-title { padding-left:20px; font-weight:bold; }
.restclients-header-url { margin-bottom:5px; }
.restclients-response-content {
    background: #fff;
    padding: 1em;
    margin: 0 -5px;
    min-height: 20px;
    background-color: #fff;
    border: 1px solid #e3e3e3;
    border-radius: 0px;
    -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,0.05);
    box-shadow: inset 0 1px 1px rgba(0,0,0,0.05);
}
.restclients-response-content label { font-weight: normal; }
.restclients-response-content input[type="submit"] { margin: 1em 0; }
.restclients-response-content ul, .restclients-response-content ol { padding-left: 20px; margin-top: 1em; }
.restclients-footer { font-size:.85em; }

.form-inline .form-control { width: auto; }
